@@ -2,7 +2,7 @@ import os, datetime, logging
 from struct import unpack
 import numpy as np
 
-from aug_sfutils import sfdics, sfhread, sfobj, manage_ed, parse_kwargs, str_byt, libddc
+from aug_sfutils import sfdics, sfhread, sfobj, manage_ed, parse_kwargs, str_byt, libddc, getlastshot
 
 PPGCLOCK = [1e-6, 1e-5, 1e-4, 1e-3]
 
@@ -15,89 +15,6 @@ def read_other_sf(*args, **kwargs):
     return SFREAD(*args, **kwargs)
 
 
-def parse_url(url, blen=100):
-    """
-    Read URL content
-    """
-
-    try:
-        import urllib3
-        url_lib = 'urllib3'
-    except:
-        try:
-            import urllib2
-            url_lib = 'urllib2'
-        except:
-            try:
-                import urllib
-                url_lib = 'urllib'
-            except:
-                logger.error('No urllib(2, 3) found')
-                return None
-
-    url_not_found = 'URLs %s not found' %url
-    if url_lib == 'urllib3':
-        http = urllib3.PoolManager()
-        try:
-            tmp = http.request('GET', url)
-        except:
-            logger.error(url_not_found)
-            return None
-        bshot = tmp.data
-    elif url_lib == 'urllib2':
-        try:
-            bshot = urllib2.urlopen(url).read(blen)
-        except:
-            logger.error(url_not_found)
-            return None
-    elif url_lib == 'urllib':
-        try:
-            bshot = request.urlopen(url).read()
-        except:
-            logger.error(url_not_found)
-            return None
-
-    return bshot
-
-
-def getlastshot():
-    """
-    Gets last shot number from the AUG webpage(s)
-    """
-
-    try:
-        from . import journal
-        return journal.getLastShot()
-    except:
-        pass
-    url1 = 'http://ssr-mir.aug.ipp.mpg.de:9090/Diag/ShotNumber.dta'
-    url2 = 'https://www.aug.ipp.mpg.de/aug/local/aug_only/journal_today_2.html'
-    bshot = parse_url(url1)
-    if bshot is None:
-        page = parse_url(url2, blen=5000)
-        if page is None:
-            return None
-        else:
-            page = str_byt.to_str(page)
-            idx = page.find("Current shot:")
-            if idx < 0:
-                logger.warning('Missing substring "Current shot:" in %s, exiting' %url2)
-                return None
-            substr = page[idx:idx+30]
-            a = substr.find('>')+1
-            b = substr.find('<', a)
-            nshot = int(substr[a:b])-1
-    else:
-        sshot = str_byt.to_str(bshot)
-        try:
-            nshot = int(sshot)
-        except:
-            logger.error('ERROR sfread.getlastshot: cannot convert string %s to integer' %sshot)
-            nshot = None
-
-    return nshot
-
-
 def getcti_ts06(nshot):
     """
     Gets the absolute time (ns) of a discharge trigger 
@@ -203,7 +120,7 @@ class SFREAD:
                         diag = args[1].strip()
             if 'nshot' not in locals(): 
                 logger.warning('No argument is a shot number (int), taking last AUG shot')
-                nshot = getlastshot()
+                nshot = getlastshot.getlastshot()
             if 'diag' not in locals():
                 diag = input('Please enter a diag_name (str(3), no delimiter):\n')
 
@@ -582,17 +499,16 @@ class SFREAD:
 
 
     def get_ts06(self):
-
+# Look anywhere in the diagsnostic's Devices
         t606 = None
-        for obj, val in self.sfh.items():
-            if hasattr(val, 'obj_type'):
-                if val.obj_type == 3:
-                    ps = self.getparset(obj)
-                    if 'TS06' in ps.keys():
-                        ts6 = ps['TS06']
-                        if ts6 > 1e15:
-                            ts06 = ts6
-                            break
+        for obj in self.parsets:
+            if self.sfh[obj].obj_type == 3:
+                ps = self.getparset(obj)
+                if 'TS06' in ps.keys():
+                    ts6 = ps['TS06']
+                    if ts6 > 1e15:
+                        ts06 = ts6
+                        break
         return ts06
 
 
